Gala
====

Gala is a Python package for Galactic and gravitational dynamics.

|PyPI| |Affiliated package| |Coverage Status| |Build status|

Documentation
-------------

|Documentation Status|

The documentation for ``Gala`` is hosted on `Read the docs
<http://gala.adrian.pw>`_.

Installation and Dependencies
-----------------------------

The easiest way to get Gala is to install with pip::

    pip install astro-gala

See the `installation
instructions <http://gala.adrian.pw/en/latest/install.html>`_ in the
`documentation <http://gala.adrian.pw>`_ for more information.

Attribution
-----------

|JOSS| |DOI|

If you make use of this code, please cite the `JOSS <http://joss.theoj.org>`_
paper::

    @article{gala,
      doi = {10.21105/joss.00388},
      url = {https://doi.org/10.21105%2Fjoss.00388},
      year = 2017,
      month = {oct},
      publisher = {The Open Journal},
      volume = {2},
      number = {18},
      author = {Adrian M. Price-Whelan},
      title = {Gala: A Python package for galactic dynamics},
      journal = {The Journal of Open Source Software}
    }

Please consider also citing the Zenodo DOI |DOI| as a software citation::

    @misc{Price-Whelan:2017,
      author       = {Adrian Price-Whelan and
                      Brigitta Sipocz and
                      Syrtis Major and
                      Semyeong Oh},
      title        = {adrn/gala: v0.2.1},
      month        = jul,
      year         = 2017,
      doi          = {10.5281/zenodo.833339},
      url          = {https://doi.org/10.5281/zenodo.833339}
    }

License
-------

|License|

Copyright 2013-2017 Adrian Price-Whelan and contributors.

``Gala`` is free software made available under the MIT License. For details see
the `LICENSE <https://github.com/adrn/gala/blob/master/LICENSE>`_ file.

.. |Coverage Status| image:: https://coveralls.io/repos/adrn/gala/badge.svg?branch=master&service=github
   :target: https://coveralls.io/github/adrn/gala?branch=master
.. |Build status| image:: http://img.shields.io/travis/adrn/gala/master.svg?style=flat
   :target: http://travis-ci.org/adrn/gala
.. |License| image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
   :target: https://github.com/adrn/gala/blob/master/LICENSE
.. |PyPI| image:: https://badge.fury.io/py/astro-gala.svg
   :target: https://badge.fury.io/py/astro-gala
.. |Documentation Status| image:: https://readthedocs.org/projects/gala-astro/badge/?version=latest
   :target: http://gala-astro.readthedocs.io/en/latest/?badge=latest
.. |Affiliated package| image:: https://img.shields.io/badge/astropy-affiliated%20package-orange.svg
   :target: http://astropy.org/affiliated
.. |JOSS| image:: http://joss.theoj.org/papers/10.21105/joss.00388/status.svg
   :target: http://joss.theoj.org/papers/10.21105/joss.00388
.. |DOI| image:: https://zenodo.org/badge/17577779.svg
   :target: https://zenodo.org/badge/latestdoi/17577779
.. |ASCL| image:: https://img.shields.io/badge/ascl-1707.006-blue.svg?colorB=262255
   :target: http://ascl.net/1707.006

Contributors
------------

See the `AUTHORS.rst <https://github.com/adrn/gala/blob/master/AUTHORS.rst>`_
file for a complete list of contributors to the project.
